{% set docker = pillar.get('docker', {}) %}
{% set volume = docker.volume_root | default('/srv/docker') ~ '/cadvisor' %}
{% set image = 'google/cadvisor:latest' %}
{% set cadvisor = pillar.get('cadvisor', {}) %}
{% set metrics = cadvisor.get('metrics', {}) %}
{% set port = '9999' %}

include:
  - docker

/etc/ferm/conf.d/40-cadvisor.conf:
  file.absent: []

docker-image-{{ image }}:
  docker_image.present:
    - name: {{ image }}
    - force: true
    - require:
      - pkg: docker

{% if metrics %}
apache2-utils:
  pkg.installed: []

docker-volume-cadvisor:
  file.directory:
    - name: {{ volume }}
    - makedirs: True
    - require:
      - file: docker-volume-root

cadvisor-htpasswd:
  webutil.user_exists:
    - name: {{ metrics.get('user', 'monitoring') }}
    - password: {{ metrics.password }}
    - htpasswd_file: {{ volume }}/htpasswd
    - options: B
    - require:
      - pkg: apache2-utils
{% endif %}

docker-container-cadvisor:
  docker_container.running:
    - image: {{ image }}
    - name: cadvisor
    - command: {% if metrics %}-http_auth_file /htpasswd {% endif %} all
    - restart_policy: always
    - port_bindings:
      - "{{ port }}:8080"
    - binds:
      - /:/rootfs:ro
      - /var/run:/var/run:ro
      - /sys:/sys:ro
      - /var/lib/docker/:/var/lib/docker:ro
      - /dev/disk/:/dev/disk:ro
      {% if metrics %}
      - {{ volume }}/htpasswd:/htpasswd
      {% endif %}
    - require:
      - docker_image: docker-image-{{ image }}
      {% if metrics %}
      - webutil: cadvisor-htpasswd
      {% endif %}
    - watch:
      - docker_image: docker-image-{{ image }}

prometheus_cadvisor_export:
  grains.present:
    - value: {{ grains['fqdn'] }}:{{ port }}
