{%- from 'docker/map.jinja' import docker with context %}

docker:
  pkgrepo.managed:
    - humanname: docker
    - name: {{ docker.apt_repo }}
    - file: /etc/apt/sources.list.d/docker.list
    - clean_file: True
    - key_url: salt://docker/files/docker.gpg
    - require:
      - pkg: apt-transport-https
  pkg.installed:
    - pkgs:
      - docker-ce{% if 'version' in docker %}: {{ docker.version }}{% endif %}
      - python-docker
      - python3-docker
    - require:
      - pkgrepo: docker
{% if 'version' in docker %}
  file.managed:
    - contents: |
        Explanation: Pin the docker version
        Package: docker-ce
        Pin: version {{ docker.version }}
        Pin-Priority: 1001
{% else %}
  file.absent:
{% endif %}
    - name: /etc/apt/preferences.d/docker-ce-pin-1001
  service.running:
    - enable: True
    - watch:
      - file: /etc/systemd/system/docker.service.d/override.conf
    - require:
      - pkg: docker

/etc/ferm/conf.d/40-docker.conf:
  file.managed:
    - source: salt://docker/files/ferm.conf.j2
    - user: root
    - group: root
    - mode: 644
    - makedirs: True
    - template: jinja
    - require_in:
      - file: ferm

docker-volume-root:
  file.directory:
    - name: {{ docker.volume_root | default('/srv/docker') }}
    - makedirs: True
    - require:
      - pkg: docker

/etc/systemd/system/docker.service.d/override.conf:
  file.managed:
    - user: root
    - group: root
    - mode: 644
    - makedirs: True
    - contents: |
        [Service]
        # keep empty ExecStart= to flush previous entries
        ExecStart=
        ExecStart=/usr/bin/dockerd -H fd:// --experimental \
                  --storage-driver={{ docker.storagedriver | default('overlay2') }}{% if docker.get('ipv6') %} \
                  --ipv6 --fixed-cidr-v6 {{ docker.ipv6 }}{%- endif %}
    - require:
      - pkg: docker

include:
  - apt.transport.https
  - apt.dependencies
  - docker.images
  - docker.container
  - cadvisor
