{%- from 'grafana/map.jinja' import grafana with context %}

include:
  - apt.transport.https

grafana:
  pkgrepo.managed:
    - humanname: grafana
    - name: {{ grafana.apt_repo }}
    - key_url: https://packages.grafana.com/gpg.key
    - file: /etc/apt/sources.list.d/grafana.list
    - clean_file: true
  pkg.installed: []

grafana-server:
  service.running:
    - enable: True
    - watch:
      - file: /etc/default/grafana-server
      - file: /etc/grafana/grafana.ini
    - require:
      - pkg: grafana

/etc/default/grafana-server:
  file.managed:
    - source: salt://grafana/files/grafana-server-default
    - user: root
    - group: root
    - mode: 644
    - require:
      - pkg: grafana

/etc/grafana/grafana.ini:
  file.managed:
    - source: salt://grafana/files/grafana.ini
    - user: root
    - group: root
    - mode: 644
    - require:
      - pkg: grafana

prometheus_ffm_grafana:
  grafana4_datasource.present:
    - name: prometheus.ffm.freifunk.net
    - type: prometheus
    - url: https://prometheus.ffm.freifunk.net
    - access: proxy
    - is_default: true

graphite_ffm_grafana:
  grafana4_datasource.present:
    - name: graphite.ffm.freifunk.net
    - type: graphite
    - url: https://graphite.ffm.freifunk.net
    - access: proxy
    - is_default: false

grafana prometheus alertmanager datasource plugin tarball:
  archive.extracted:
    - source: https://grafana.com/api/plugins/camptocamp-prometheus-alertmanager-datasource/versions/0.0.6/download
    - archive_format: zip
    - source_hash: sha256=7072a41d8ed0b10c977e1ad43dc2d1a70df3337ce69f65f101891dba651e9bd7
    - name: /var/lib/grafana/plugins/camptocamp-prometheus-alertmanager-datasource/
    - user: grafana
    - group: grafana
    - watch_in:
      - service: grafana-server

prometheus_grafana_export:
  grains.present:
    - require:
      - pkg: grafana
      - file: /etc/grafana/grafana.ini
    - value: {{ grafana.domain }}:443
