{% set transport_interface = salt['pillar.get']('ferm:transport_interface', 'ens14') %} 
/etc/network/interfaces.d/{{ transport_interface }}:
  file.managed:
    - source: salt://network/files/transport_interface.j2
    - mode: 644
    - user: root
    - group: root
    - template: jinja
    - context:
        name: {{ transport_interface }}

/etc/ferm/conf.d/20-{{ transport_interface }}-vxlan.conf:
  file.managed:
    - source: salt://network/files/ferm-vxlan.conf.j2
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - context:
        name: {{ transport_interface }}

{% for domain in pillar.get('domains', {}).keys() %}
{% set domain_id = salt['pillar.get']('domains:%s:domain_id'|format(domain)) %}
/etc/network/interfaces.d/dom{{ domain_id }}:
  file.managed:
    - source: salt://network/files/interfaces-domain.j2
    - mode: 644
    - user: root
    - group: root
    - template: jinja
    - context:
        domain: {{ domain }}
        domain_id: {{ domain_id }}

{% if 'gateway' in pillar.get('roles', []) %}
/etc/ferm/conf.d/20-dom{{ domain_id }}.conf:
  file.managed:
    - source: salt://network/files/ferm-domain-batman.conf.j2
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - context:
        domain: {{ domain }}
        domain_id: {{ domain_id }}
        routing: {{ pillar['routing'] }}
{% endif %}

ifup-dom{{ domain_id }}-br:
  cmd.run:
    - name: /sbin/ifup dom{{ domain_id }}-br
    - unless: /sbin/ip link show dev dom{{ domain_id }}-br
    - require:
      - cmd: ifreload
{% endfor %}
